=======
History
=======

0.3.0 (pending)
---------------

* Provider state setup functions now raise NotImplementedError by default.
* Format output files with target line length option.
* Improve output to console, add quiet option.

0.2.1 (2021-09-01)
------------------

* Fix test client not setting content type.

0.2.0 (2021-09-01)
------------------

* Improve output for failed test cases.

0.1.2 (2021-08-25)
------------------

* Fix bump2version config

0.1.1 (2021-08-24)
------------------

* Fix templates missing from distributed package.

0.1.0 (2021-08-23)
------------------

* First release on PyPI.
